@@ -14,7 +14,10 @@ import constructs._jsii
 import ros_cdk_core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@alicloud/ros-cdk-kafka", "1.0.9", __name__[0:-6], "ros-cdk-kafka@1.0.9.jsii.tgz"
+    "@alicloud/ros-cdk-kafka",
+    "1.0.11",
+    __name__[0:-6],
+    "ros-cdk-kafka@1.0.11.jsii.tgz",
 )
 
 __all__ = [
